import requests
import pyperclip

def copy_content_to_clipboard(url):
    response = requests.get(url)
    if response.status_code == 200:
        content = response.text
        pyperclip.copy(content)
        print("success.")
    else:
        print("failed")

def main():
    name = input("Enter a name: ")
    url = f"https://raw.githubusercontent.com/Pranavkak/help/main/{name}.txt"
    copy_content_to_clipboard(url)

if __name__ == "__main__":
    main()



from setuptools import setup

setup(
    name='anshukak',
    version='1.0',
    packages=['anshukak'],
    entry_points={
        'console_scripts': [
            'anshukak = anshukak.main:main'
        ]
    },
    install_requires=[
        'requests',
        'pyperclip'
    ],
)
